@@ -21,33 +21,40 @@ adjust_om_val <- function(
     X = data_observed$data[, data_observed$exposure],
     Ystar = data_observed$data[, data_observed$outcome]
   )
-  df <- bind_cols(df, data_observed$data[, data_observed$confounders])
+  df <- bind_cols(
+    df,
+    data_observed$data %>%
+      select(all_of(data_observed$confounders))
+  )
 
   df_val <- data.frame(
     X = data_validation$data[, data_validation$true_exposure],
     Y = data_validation$data[, data_validation$true_outcome],
     Ystar = data_validation$data[, data_validation$misclassified_outcome]
   )
+  df_val <- bind_cols(
+    df_val,
+    data_validation$data %>%
+      select(all_of(data_validation$confounders))
+  )
 
-  if (all(df$X %in% 0:1)) {
-    if (!all(df_val$X %in% 0:1)) {
-      stop("Exposures from both datasets must both be binary or both be continuous.")
-    }
-  }
-  if (all(df$Y %in% 0:1)) {
-    if (!all(df_val$Y %in% 0:1) || !all(df_val$Ystar %in% 0:1)) {
-      stop("Outcomes from both datasets must both be binary or both be continuous.")
-    }
-  }
-  if (!all(df$Ystar %in% 0:1)) {
-    stop("Misclassified outcome in observed data must be a binary integer.")
-  }
-  if (!all(df_val$Ystar %in% 0:1)) {
-    stop("Misclassified outcome in validation data must be a binary integer.")
-  }
-  if (!all(df_val$Y %in% 0:1)) {
-    stop("True outcome in validation data must be a binary integer.")
-  }
+  force_match(
+    df$X,
+    df_val$X,
+    "Exposures from both datasets must both be binary or both be continuous."
+  )
+  force_binary(
+    df$Ystar,
+    "Outcome in observed data must be a binary integer."
+  )
+  force_binary(
+    df_val$Ystar,
+    "Misclassified outcome in validation data must be a binary integer."
+  )
+  force_binary(
+    df_val$Y,
+    "True outcome in validation data must be a binary integer."
+  )
 
   y_mod <- glm(Y ~ X + Ystar + .,
     family = binomial(link = "logit"),
@@ -65,7 +72,7 @@ adjust_om_val <- function(
   df$Ypred <- rbinom(n, 1, plogis(y_pred))
 
   final <- glm(
-    Ypred ~ X + .,
+    Ypred ~ X + . - Ystar,
     family = binomial(link = "logit"),
     data = df
   )
@@ -202,8 +209,9 @@ adjust_omc <- function(
 #' `adjust_om` returns the exposure-outcome odds ratio and confidence
 #' interval, adjusted for outcome misclassificaiton.
 #'
-#' Values for the regression coefficients can be applied as
-#' fixed values or as single draws from a probability
+#' Bias adjustment can be performed by inputting either a validation dataset or
+#' the necessary bias parameters. Values for the bias parameters
+#' can be applied as fixed values or as single draws from a probability
 #' distribution (ex: `rnorm(1, mean = 2, sd = 1)`). The latter has
 #' the advantage of allowing the researcher to capture the uncertainty
 #' in the bias parameter estimates. To incorporate this uncertainty in the
@@ -277,13 +285,13 @@ adjust_om <- function(
     data_validation = NULL,
     y_model_coefs = NULL,
     level = 0.95) {
+  if (
+    (!is.null(data_validation) && !is.null(y_model_coefs)) ||
+      (is.null(data_validation) && is.null(y_model_coefs))
+  ) {
+    stop("One of data_validation or y_model_coefs must be non-null.")
+  }
   data <- data_observed$data
-  n <- nrow(data)
-  confounders <- data_observed$confounders
-  len_c <- length(confounders)
-
-  x <- data[, data_observed$exposure]
-  ystar <- data[, data_observed$outcome]
 
   if (!is.null(data_validation)) {
     final <- adjust_om_val(
