@@ -21,7 +21,11 @@ adjust_sel_val <- function(
     X = data_observed$data[, data_observed$exposure],
     Y = data_observed$data[, data_observed$outcome]
   )
-  df <- bind_cols(df, data_observed$data[, data_observed$confounders])
+  df <- bind_cols(
+    df,
+    data_observed$data %>%
+      select(all_of(data_observed$confounders))
+  )
 
   if (all(df$Y %in% 0:1)) {
     y_binary <- TRUE
@@ -35,19 +39,20 @@ adjust_sel_val <- function(
     S = data_validation$data[, data_validation$selection]
   )
 
-  if (all(df$X %in% 0:1)) {
-    if (!all(df_val$X %in% 0:1)) {
-      stop("Exposures from both datasets must match as binary or continuous.")
-    }
-  }
-  if (all(df$Y %in% 0:1)) {
-    if (!all(df_val$Y %in% 0:1)) {
-      stop("Outcomes from both datasets must match as binary or continuous.")
-    }
-  }
-  if (!all(df_val$S %in% 0:1)) {
-    stop("Selection indicator in validation data must be a binary integer.")
-  }
+  force_match(
+    df$X,
+    df_val$X,
+    "Exposures from both datasets must both be binary or both be continuous."
+  )
+  force_match(
+    df$Y,
+    df_val$Y,
+    "Outcomes from both datasets must both be binary or both be continuous."
+  )
+  force_binary(
+    df_val$S,
+    "Selection indicator in validation data must be a binary integer."
+  )
 
   s_mod <- glm(S ~ X + Y,
     family = binomial(link = "logit"),
@@ -227,8 +232,9 @@ adjust_sel_coef <- function(
 #' `adjust_sel` returns the exposure-outcome odds ratio and confidence
 #' interval, adjusted for selection bias.
 #'
-#' Values for the regression coefficients can be applied as
-#' fixed values or as single draws from a probability
+#' Bias adjustment can be performed by inputting either a validation dataset or
+#' the necessary bias parameters. Values for the bias parameters
+#' can be applied as fixed values or as single draws from a probability
 #' distribution (ex: `rnorm(1, mean = 2, sd = 1)`). The latter has
 #' the advantage of allowing the researcher to capture the uncertainty
 #' in the bias parameter estimates. To incorporate this uncertainty in the
@@ -300,10 +306,13 @@ adjust_sel <- function(
     data_validation = NULL,
     s_model_coefs = NULL,
     level = 0.95) {
+  if (
+    (!is.null(data_validation) && !is.null(s_model_coefs)) ||
+      (is.null(data_validation) && is.null(s_model_coefs))
+  ) {
+    stop("One of data_validation or s_model_coefs must be non-null.")
+  }
   data <- data_observed$data
-  n <- nrow(data)
-  confounders <- data_observed$confounders
-  len_c <- length(confounders)
 
   x <- data[, data_observed$exposure]
   y <- data[, data_observed$outcome]
@@ -314,10 +323,6 @@ adjust_sel <- function(
     y_binary <- FALSE
   }
 
-  s1_0 <- s_model_coefs[1]
-  s1_x <- s_model_coefs[2]
-  s1_y <- s_model_coefs[3]
-
   if (!is.null(data_validation)) {
     final <- adjust_sel_val(
       data_observed,
