@@ -587,3 +587,27 @@ test_that("3 confounders: odds ratio and confidence interval output", {
     size = 2
   )
 })
+
+# adjust with validation data
+
+or_val <- adjust_em_om(
+  data_observed = data_observed(
+    df_em_om,
+    exposure = "Xstar",
+    outcome = "Ystar",
+    confounders = c("C1", "C2", "C3")
+  ),
+  data_validation = data_validation(
+    df_em_om_source,
+    true_exposure = "X",
+    true_outcome = "Y",
+    confounders = c("C1", "C2", "C3"),
+    misclassified_exposure = "Xstar",
+    misclassified_outcome = "Ystar"
+  )
+)
+
+test_that("adjust_em_om, validation data", {
+  expect_gt(or_val$estimate, or_true - 0.1)
+  expect_lt(or_val$estimate, or_true + 0.1)
+})
