@@ -10,24 +10,37 @@ df_uc_om_sel$X_cont <- plogis(df_uc_om_sel$X) +
 
 # 0 confounders
 
-nobias_model <- glm(Y ~ X + U,
-                    family = binomial(link = "logit"),
-                    data = df_uc_om_sel_source)
+nobias_model <- glm(
+  Y ~ X + U,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
 
-u_model <- glm(U ~ X + Y,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
-y_model <- glm(Y ~ X + Ystar,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
-s_model <- glm(S ~ X + Ystar,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
+u_model <- glm(
+  U ~ X + Y,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
+y_model <- glm(
+  Y ~ X + Ystar,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
+s_model <- glm(
+  S ~ X + Ystar,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
 
-single_run <- adjust_uc_om_sel(
+df_observed <- data_observed(
   df_uc_om_sel,
   exposure = "X_cont",
   outcome = "Ystar",
+  confounders = NULL
+)
+
+single_run <- adjust_uc_om_sel(
+  df_observed,
   u_model_coefs = c(
     u_model$coef[1],
     u_model$coef[2],
@@ -48,10 +61,14 @@ single_run <- adjust_uc_om_sel(
 est <- vector()
 for (i in 1:nreps) {
   bdf <- df_uc_om_sel[sample(seq_len(n), n, replace = TRUE), ]
-  results <- adjust_uc_om_sel(
+  df_observed <- data_observed(
     bdf,
     exposure = "X",
     outcome = "Ystar",
+    confounders = NULL
+  )
+  results <- adjust_uc_om_sel(
+    df_observed,
     u_model_coefs = c(
       u_model$coef[1],
       u_model$coef[2],
@@ -86,25 +103,37 @@ test_that("0 confounders: odds ratio and confidence interval output", {
 
 # 1 confounder
 
-nobias_model <- glm(Y ~ X + C1 + U,
-                    family = binomial(link = "logit"),
-                    data = df_uc_om_sel_source)
+nobias_model <- glm(
+  Y ~ X + C1 + U,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
 
-u_model <- glm(U ~ X + Y,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
-y_model <- glm(Y ~ X + Ystar + C1,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
-s_model <- glm(S ~ X + Ystar + C1,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
+u_model <- glm(
+  U ~ X + Y,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
+y_model <- glm(
+  Y ~ X + Ystar + C1,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
+s_model <- glm(
+  S ~ X + Ystar + C1,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
+
+df_observed <- data_observed(
+  df_uc_om_sel,
+  exposure = "X_cont",
+  outcome = "Ystar",
+  confounders = "C1"
+)
 
 single_run <- adjust_uc_om_sel(
-  df_uc_om_sel,
-  "X_cont",
-  "Ystar",
-  "C1",
+  df_observed,
   u_model_coefs = c(
     u_model$coef[1],
     u_model$coef[2],
@@ -127,11 +156,14 @@ single_run <- adjust_uc_om_sel(
 est <- vector()
 for (i in 1:nreps) {
   bdf <- df_uc_om_sel[sample(seq_len(n), n, replace = TRUE), ]
-  results <- adjust_uc_om_sel(
+  df_observed <- data_observed(
     bdf,
-    "X",
-    "Ystar",
-    "C1",
+    exposure = "X",
+    outcome = "Ystar",
+    confounders = "C1"
+  )
+  results <- adjust_uc_om_sel(
+    df_observed,
     u_model_coefs = c(
       u_model$coef[1],
       u_model$coef[2],
@@ -168,25 +200,37 @@ test_that("1 confounder: odds ratio and confidence interval output", {
 
 # 2 confounders
 
-nobias_model <- glm(Y ~ X + C1 + C2 + U,
-                    family = binomial(link = "logit"),
-                    data = df_uc_om_sel_source)
+nobias_model <- glm(
+  Y ~ X + C1 + C2 + U,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
 
-u_model <- glm(U ~ X + Y,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
-y_model <- glm(Y ~ X + Ystar + C1 + C2,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
-s_model <- glm(S ~ X + Ystar + C1 + C2,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
+u_model <- glm(
+  U ~ X + Y,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
+y_model <- glm(
+  Y ~ X + Ystar + C1 + C2,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
+s_model <- glm(
+  S ~ X + Ystar + C1 + C2,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
+
+df_observed <- data_observed(
+  df_uc_om_sel,
+  exposure = "X_cont",
+  outcome = "Ystar",
+  confounders = c("C1", "C2")
+)
 
 single_run <- adjust_uc_om_sel(
-  df_uc_om_sel,
-  "X_cont",
-  "Ystar",
-  c("C1", "C2"),
+  df_observed,
   u_model_coefs = c(
     u_model$coef[1],
     u_model$coef[2],
@@ -211,11 +255,14 @@ single_run <- adjust_uc_om_sel(
 est <- vector()
 for (i in 1:nreps) {
   bdf <- df_uc_om_sel[sample(seq_len(n), n, replace = TRUE), ]
-  results <- adjust_uc_om_sel(
+  df_observed <- data_observed(
     bdf,
-    "X",
-    "Ystar",
-    c("C1", "C2"),
+    exposure = "X",
+    outcome = "Ystar",
+    confounders = c("C1", "C2")
+  )
+  results <- adjust_uc_om_sel(
+    df_observed,
     u_model_coefs = c(
       u_model$coef[1],
       u_model$coef[2],
@@ -254,25 +301,37 @@ test_that("2 confounders: odds ratio and confidence interval output", {
 
 # 3 confounders
 
-nobias_model <- glm(Y ~ X + C1 + C2 + C3 + U,
-                    family = binomial(link = "logit"),
-                    data = df_uc_om_sel_source)
+nobias_model <- glm(
+  Y ~ X + C1 + C2 + C3 + U,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
 
-u_model <- glm(U ~ X + Y,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
-y_model <- glm(Y ~ X + Ystar + C1 + C2 + C3,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
-s_model <- glm(S ~ X + Ystar + C1 + C2 + C3,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
+u_model <- glm(
+  U ~ X + Y,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
+y_model <- glm(
+  Y ~ X + Ystar + C1 + C2 + C3,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
+s_model <- glm(
+  S ~ X + Ystar + C1 + C2 + C3,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
+
+df_observed <- data_observed(
+  df_uc_om_sel,
+  exposure = "X_cont",
+  outcome = "Ystar",
+  confounders = c("C1", "C2", "C3")
+)
 
 single_run <- adjust_uc_om_sel(
-  df_uc_om_sel,
-  "X_cont",
-  "Ystar",
-  c("C1", "C2", "C3"),
+  df_observed,
   u_model_coefs = c(
     u_model$coef[1],
     u_model$coef[2],
@@ -299,11 +358,14 @@ single_run <- adjust_uc_om_sel(
 est <- vector()
 for (i in 1:nreps) {
   bdf <- df_uc_om_sel[sample(seq_len(n), n, replace = TRUE), ]
-  results <- adjust_uc_om_sel(
+  df_observed <- data_observed(
     bdf,
-    "X",
-    "Ystar",
-    c("C1", "C2", "C3"),
+    exposure = "X",
+    outcome = "Ystar",
+    confounders = c("C1", "C2", "C3")
+  )
+  results <- adjust_uc_om_sel(
+    df_observed,
     u_model_coefs = c(
       u_model$coef[1],
       u_model$coef[2],
@@ -356,23 +418,32 @@ df_uc_om_sel$X_cont <- plogis(df_uc_om_sel$X) +
 
 # 0 confounders
 
-nobias_model <- glm(Y ~ X + U,
-                    family = binomial(link = "logit"),
-                    data = df_uc_om_sel_source)
+nobias_model <- glm(
+  Y ~ X + U,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
 
 # uy_model <- multinom(
 #   paste(U, Y) ~ X + Ystar,
 #   data = df_uc_om_sel_source
 # )
 
-s_model <- glm(S ~ X + Ystar,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
+s_model <- glm(
+  S ~ X + Ystar,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
 
-single_run <- adjust_uc_om_sel(
+df_observed <- data_observed(
   df_uc_om_sel,
   exposure = "X_cont",
   outcome = "Ystar",
+  confounders = NULL
+)
+
+single_run <- adjust_uc_om_sel(
+  df_observed,
   u1y0_model_coefs = c(-0.32, 0.59, 0.01),
   u0y1_model_coefs = c(-2.98, 0.71, 1.65),
   u1y1_model_coefs = c(-2.59, 1.27, 1.64),
@@ -386,10 +457,14 @@ single_run <- adjust_uc_om_sel(
 est <- vector()
 for (i in 1:nreps) {
   bdf <- df_uc_om_sel[sample(seq_len(n), n, replace = TRUE), ]
-  results <- adjust_uc_om_sel(
+  df_observed <- data_observed(
     bdf,
     exposure = "X",
     outcome = "Ystar",
+    confounders = NULL
+  )
+  results <- adjust_uc_om_sel(
+    df_observed,
     u1y0_model_coefs = c(-0.32, 0.59, 0.01),
     u0y1_model_coefs = c(-2.98, 0.71, 1.65),
     u1y1_model_coefs = c(-2.59, 1.27, 1.64),
@@ -417,24 +492,32 @@ test_that("0 confounders: odds ratio and confidence interval output", {
 
 # 1 confounder
 
-nobias_model <- glm(Y ~ X + C1 + U,
-                    family = binomial(link = "logit"),
-                    data = df_uc_om_sel_source)
+nobias_model <- glm(
+  Y ~ X + C1 + U,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
 
 # uy_model <- multinom(
 #   paste(U, Y) ~ X + Ystar + C1,
 #   data = df_uc_om_sel_source
 # )
 
-s_model <- glm(S ~ X + Ystar + C1,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
+s_model <- glm(
+  S ~ X + Ystar + C1,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
 
-single_run <- adjust_uc_om_sel(
+df_observed <- data_observed(
   df_uc_om_sel,
   exposure = "X_cont",
   outcome = "Ystar",
-  confounders = "C1",
+  confounders = "C1"
+)
+
+single_run <- adjust_uc_om_sel(
+  df_observed,
   u1y0_model_coefs = c(-0.29, 0.60, 0.01, -0.08),
   u0y1_model_coefs = c(-3.20, 0.68, 1.65, 0.42),
   u1y1_model_coefs = c(-2.76, 1.24, 1.64, 0.32),
@@ -449,11 +532,14 @@ single_run <- adjust_uc_om_sel(
 est <- vector()
 for (i in 1:nreps) {
   bdf <- df_uc_om_sel[sample(seq_len(n), n, replace = TRUE), ]
-  results <- adjust_uc_om_sel(
+  df_observed <- data_observed(
     bdf,
     exposure = "X",
     outcome = "Ystar",
-    confounders = "C1",
+    confounders = "C1"
+  )
+  results <- adjust_uc_om_sel(
+    df_observed,
     u1y0_model_coefs = c(-0.29, 0.60, 0.01, -0.08),
     u0y1_model_coefs = c(-3.20, 0.68, 1.65, 0.42),
     u1y1_model_coefs = c(-2.76, 1.24, 1.64, 0.32),
@@ -482,24 +568,32 @@ test_that("1 confounder: odds ratio and confidence interval output", {
 
 # 2 confounders
 
-nobias_model <- glm(Y ~ X + C1 + C2 + U,
-                    family = binomial(link = "logit"),
-                    data = df_uc_om_sel_source)
+nobias_model <- glm(
+  Y ~ X + C1 + C2 + U,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
 
 # uy_model <- multinom(
 #   paste(U, Y) ~ X + Ystar + C1 + C2,
 #   data = df_uc_om_sel_source
 # )
 
-s_model <- glm(S ~ X + Ystar + C1 + C2,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
+s_model <- glm(
+  S ~ X + Ystar + C1 + C2,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
 
-single_run <- adjust_uc_om_sel(
+df_observed <- data_observed(
   df_uc_om_sel,
   exposure = "X_cont",
   outcome = "Ystar",
-  confounders = c("C1", "C2"),
+  confounders = c("C1", "C2")
+)
+
+single_run <- adjust_uc_om_sel(
+  df_observed,
   u1y0_model_coefs = c(-0.31, 0.60, 0.01, -0.08, 0.10),
   u0y1_model_coefs = c(-3.07, 0.66, 1.65, 0.42, -0.85),
   u1y1_model_coefs = c(-2.63, 1.22, 1.64, 0.32, -0.77),
@@ -515,11 +609,14 @@ single_run <- adjust_uc_om_sel(
 est <- vector()
 for (i in 1:nreps) {
   bdf <- df_uc_om_sel[sample(seq_len(n), n, replace = TRUE), ]
-  results <- adjust_uc_om_sel(
+  df_observed <- data_observed(
     bdf,
     exposure = "X",
     outcome = "Ystar",
-    confounders = c("C1", "C2"),
+    confounders = c("C1", "C2")
+  )
+  results <- adjust_uc_om_sel(
+    df_observed,
     u1y0_model_coefs = c(-0.31, 0.60, 0.01, -0.08, 0.10),
     u0y1_model_coefs = c(-3.07, 0.66, 1.65, 0.42, -0.85),
     u1y1_model_coefs = c(-2.63, 1.22, 1.64, 0.32, -0.77),
@@ -549,24 +646,32 @@ test_that("2 confounders: odds ratio and confidence interval output", {
 
 # 3 confounders
 
-nobias_model <- glm(Y ~ X + C1 + C2 + C3 + U,
-                    family = binomial(link = "logit"),
-                    data = df_uc_om_sel_source)
+nobias_model <- glm(
+  Y ~ X + C1 + C2 + C3 + U,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
 
 # uy_model <- multinom(
 #   paste(U, Y) ~ X + Ystar + C1 + C2 + C3,
 #   data = df_uc_om_sel_source
 # )
 
-s_model <- glm(S ~ X + Ystar + C1 + C2 + C3,
-               family = binomial(link = "logit"),
-               data = df_uc_om_sel_source)
+s_model <- glm(
+  S ~ X + Ystar + C1 + C2 + C3,
+  family = binomial(link = "logit"),
+  data = df_uc_om_sel_source
+)
 
-single_run <- adjust_uc_om_sel(
+df_observed <- data_observed(
   df_uc_om_sel,
   exposure = "X_cont",
   outcome = "Ystar",
-  confounders = c("C1", "C2", "C3"),
+  confounders = c("C1", "C2", "C3")
+)
+
+single_run <- adjust_uc_om_sel(
+  df_observed,
   u1y0_model_coefs = c(-0.20, 0.62, 0.01, -0.08, 0.10, -0.15),
   u0y1_model_coefs = c(-3.28, 0.63, 1.65, 0.42, -0.85, 0.26),
   u1y1_model_coefs = c(-2.70, 1.22, 1.64, 0.32, -0.77, 0.09),
@@ -583,11 +688,14 @@ single_run <- adjust_uc_om_sel(
 est <- vector()
 for (i in 1:nreps) {
   bdf <- df_uc_om_sel[sample(seq_len(n), n, replace = TRUE), ]
-  results <- adjust_uc_om_sel(
+  df_observed <- data_observed(
     bdf,
     exposure = "X",
     outcome = "Ystar",
-    confounders = c("C1", "C2", "C3"),
+    confounders = c("C1", "C2", "C3")
+  )
+  results <- adjust_uc_om_sel(
+    df_observed,
     u1y0_model_coefs = c(-0.20, 0.62, 0.01, -0.08, 0.10, -0.15),
     u0y1_model_coefs = c(-3.28, 0.63, 1.65, 0.42, -0.85, 0.26),
     u1y1_model_coefs = c(-2.70, 1.22, 1.64, 0.32, -0.77, 0.09),
@@ -614,4 +722,4 @@ test_that("3 confounders: odds ratio and confidence interval output", {
     ptype = double(),
     size = 2
   )
-})
\ No newline at end of file
+})
