@@ -7,21 +7,33 @@ df_uc_sel$Y_cont <- plogis(df_uc_sel$Y) + rnorm(nrow(df_uc_sel), mean = 0, sd =
 
 # 0 confounders
 
-nobias_model <- glm(Y ~ X + U,
-                    family = binomial(link = "logit"),
-                    data = df_uc_sel_source)
+nobias_model <- glm(
+  Y ~ X + U,
+  family = binomial(link = "logit"),
+  data = df_uc_sel_source
+)
 
-u_model <- glm(U ~ X + Y,
-               family = binomial(link = "logit"),
-               data = df_uc_sel_source)
-s_model <- glm(S ~ X + Y,
-               family = binomial(link = "logit"),
-               data = df_uc_sel_source)
+u_model <- glm(
+  U ~ X + Y,
+  family = binomial(link = "logit"),
+  data = df_uc_sel_source
+)
 
-single_run <- adjust_uc_sel(
+s_model <- glm(
+  S ~ X + Y,
+  family = binomial(link = "logit"),
+  data = df_uc_sel_source
+)
+
+df_observed <- data_observed(
   df_uc_sel,
   exposure = "X",
   outcome = "Y_cont",
+  confounders = NULL
+)
+
+single_run <- adjust_uc_sel(
+  df_observed,
   u_model_coefs = c(
     u_model$coef[1],
     u_model$coef[2],
@@ -37,10 +49,14 @@ single_run <- adjust_uc_sel(
 est <- vector()
 for (i in 1:nreps) {
   bdf <- df_uc_sel[sample(seq_len(n), n, replace = TRUE), ]
-  results <- adjust_uc_sel(
+  df_observed <- data_observed(
     bdf,
     exposure = "X",
     outcome = "Y",
+    confounders = NULL
+  )
+  results <- adjust_uc_sel(
+    df_observed,
     u_model_coefs = c(
       u_model$coef[1],
       u_model$coef[2],
@@ -70,22 +86,33 @@ test_that("odds ratio and confidence interval output", {
 
 # 1 confounder
 
-nobias_model <- glm(Y ~ X + C1 + U,
-                    family = binomial(link = "logit"),
-                    data = df_uc_sel_source)
+nobias_model <- glm(
+  Y ~ X + C1 + U,
+  family = binomial(link = "logit"),
+  data = df_uc_sel_source
+)
 
-u_model <- glm(U ~ X + Y + C1,
-               family = binomial(link = "logit"),
-               data = df_uc_sel_source)
-s_model <- glm(S ~ X + Y,
-               family = binomial(link = "logit"),
-               data = df_uc_sel_source)
+u_model <- glm(
+  U ~ X + Y + C1,
+  family = binomial(link = "logit"),
+  data = df_uc_sel_source
+)
 
-single_run <- adjust_uc_sel(
+s_model <- glm(
+  S ~ X + Y,
+  family = binomial(link = "logit"),
+  data = df_uc_sel_source
+)
+
+df_observed <- data_observed(
   df_uc_sel,
   exposure = "X",
   outcome = "Y_cont",
-  confounders = "C1",
+  confounders = "C1"
+)
+
+single_run <- adjust_uc_sel(
+  df_observed,
   u_model_coefs = c(
     u_model$coef[1],
     u_model$coef[2],
@@ -102,11 +129,14 @@ single_run <- adjust_uc_sel(
 est <- vector()
 for (i in 1:nreps) {
   bdf <- df_uc_sel[sample(seq_len(n), n, replace = TRUE), ]
-  results <- adjust_uc_sel(
+  df_observed <- data_observed(
     bdf,
     exposure = "X",
     outcome = "Y",
-    confounders = "C1",
+    confounders = "C1"
+  )
+  results <- adjust_uc_sel(
+    df_observed,
     u_model_coefs = c(
       u_model$coef[1],
       u_model$coef[2],
@@ -137,22 +167,33 @@ test_that("odds ratio and confidence interval output", {
 
 # 2 confounders
 
-nobias_model <- glm(Y ~ X + C1 + C2 + U,
-                    family = binomial(link = "logit"),
-                    data = df_uc_sel_source)
+nobias_model <- glm(
+  Y ~ X + C1 + C2 + U,
+  family = binomial(link = "logit"),
+  data = df_uc_sel_source
+)
 
-u_model <- glm(U ~ X + Y + C1 + C2,
-               family = binomial(link = "logit"),
-               data = df_uc_sel_source)
-s_model <- glm(S ~ X + Y,
-               family = binomial(link = "logit"),
-               data = df_uc_sel_source)
+u_model <- glm(
+  U ~ X + Y + C1 + C2,
+  family = binomial(link = "logit"),
+  data = df_uc_sel_source
+)
 
-single_run <- adjust_uc_sel(
+s_model <- glm(
+  S ~ X + Y,
+  family = binomial(link = "logit"),
+  data = df_uc_sel_source
+)
+
+df_observed <- data_observed(
   df_uc_sel,
   exposure = "X",
   outcome = "Y_cont",
-  confounders = c("C1", "C2"),
+  confounders = c("C1", "C2")
+)
+
+single_run <- adjust_uc_sel(
+  df_observed,
   u_model_coefs = c(
     u_model$coef[1],
     u_model$coef[2],
@@ -170,11 +211,14 @@ single_run <- adjust_uc_sel(
 est <- vector()
 for (i in 1:nreps) {
   bdf <- df_uc_sel[sample(seq_len(n), n, replace = TRUE), ]
-  results <- adjust_uc_sel(
+  df_observed <- data_observed(
     bdf,
     exposure = "X",
     outcome = "Y",
-    confounders = c("C1", "C2"),
+    confounders = c("C1", "C2")
+  )
+  results <- adjust_uc_sel(
+    df_observed,
     u_model_coefs = c(
       u_model$coef[1],
       u_model$coef[2],
@@ -206,22 +250,33 @@ test_that("odds ratio and confidence interval output", {
 
 # 3 confounders
 
-nobias_model <- glm(Y ~ X + C1 + C2 + C3 + U,
-                    family = binomial(link = "logit"),
-                    data = df_uc_sel_source)
+nobias_model <- glm(
+  Y ~ X + C1 + C2 + C3 + U,
+  family = binomial(link = "logit"),
+  data = df_uc_sel_source
+)
 
-u_model <- glm(U ~ X + Y + C1 + C2 + C3,
-               family = binomial(link = "logit"),
-               data = df_uc_sel_source)
-s_model <- glm(S ~ X + Y,
-               family = binomial(link = "logit"),
-               data = df_uc_sel_source)
+u_model <- glm(
+  U ~ X + Y + C1 + C2 + C3,
+  family = binomial(link = "logit"),
+  data = df_uc_sel_source
+)
 
-single_run <- adjust_uc_sel(
+s_model <- glm(
+  S ~ X + Y,
+  family = binomial(link = "logit"),
+  data = df_uc_sel_source
+)
+
+df_observed <- data_observed(
   df_uc_sel,
   exposure = "X",
   outcome = "Y_cont",
-  confounders = c("C1", "C2", "C3"),
+  confounders = c("C1", "C2", "C3")
+)
+
+single_run <- adjust_uc_sel(
+  df_observed,
   u_model_coefs = c(
     u_model$coef[1],
     u_model$coef[2],
@@ -240,11 +295,14 @@ single_run <- adjust_uc_sel(
 est <- vector()
 for (i in 1:nreps) {
   bdf <- df_uc_sel[sample(seq_len(n), n, replace = TRUE), ]
-  results <- adjust_uc_sel(
+  df_observed <- data_observed(
     bdf,
     exposure = "X",
     outcome = "Y",
-    confounders = c("C1", "C2", "C3"),
+    confounders = c("C1", "C2", "C3")
+  )
+  results <- adjust_uc_sel(
+    df_observed,
     u_model_coefs = c(
       u_model$coef[1],
       u_model$coef[2],
